@@ -555,7 +555,7 @@ class ProgressState(StartState):
         self.parent.printer.up(1)("")
 
     def setProgress(self, percent, short_message, long_message):
-        if 0 < percent > 100:
+        if not 0 <= percent <= 100:
             self.breakTask()
         else:
             self.parent.progress.update(percent)
